<?php
/* <meta content="charset=UTF-8"> */

class Station extends Controller
{
  /**
   * コンストラクター
   * @access public
   * @return void
   */
  function Station() {
    // 親クラスのコンストラクターを実行
    parent::Controller();

    // ライブラリーをロード
    $this->load->library(array('pagination', 'session'));
    // ヘルパーをロード
    $this->load->helper(array('url', 'security', 'html'));
    // Yahooapiモデルをロード
    $this->load->model('Yahooapi');
    // 設定ファイルをロード
    $conf = $this->config->load('gurume');

    // Yahoo!地図Web APIのアプリケーションIDをYahooapiモデルにセット
    $this->Yahooapi->setApiKey($this->config->item('yahoo'));
  }

  /**
   * 最寄り駅の一覧ページ
   * @return void
   */
  function index() {
    // ビューへ渡す配列変数を作成
    $page = array();
    // タイトルを設定
    $page['title'] = '最寄り駅';

    // 緯度経度をURIから取得する
    $lat = $this->uri->segment(3, '35.65678');
    $lon = $this->uri->segment(4, '139.733555');

    // 緯度経度の検証
    if (!$this->_checkLatLon($lat, $lon)) {
      die('不正な入力です');
    }

    // 緯度経度をYahooapiモデルに設定
    $this->Yahooapi->setLatitude($lat);
    $this->Yahooapi->setLongitude($lon);

    try {
      // Yahooapiモデルから最寄り駅の一覧を取得
      $stationLists = $this->Yahooapi->get();
    }
    catch (Exception $e) {
      // @todo エラーページ
      echo $e->getMessage();
      exit();
    }
    //var_dump($stationLists);

    // 最寄り駅が1件以上あった場合
    if ($stationLists->Count >= 1) {
      // 表示しやすいように配列変数に変換
      foreach ($stationLists->Item as $stationList) {
        $item = array();
        $item['title']   = $stationList->Title;
        $item['address'] = $stationList->Address;
        $item['lat']     = $stationList->DatumTky97->Lat;
        $item['lon']     = $stationList->DatumTky97->Lon;
        $station['items'][] = $item;
      }

      // 取得した最寄り駅のデータをXSSフィルタに通す
      $station = $this->input->xss_clean($station);

      // station_index_listビューでHTMLを作成して配列変数$pageに代入
      $page['appMain'] = $this->load->view('station_index_list', $station, TRUE);
    } else {
      // 最寄り駅が見つからなかった場合
      $page['appMain'] = '見つかりませんでした';
    }

    // ビューを出力
    $this->load->view('station_index', $page);
  }

  /**
   * 駅周辺の地図ページ
   * @return void
   */
  function map() {
    // ビューへ渡す配列変数を作成
    $page = array();
    // タイトルを設定
    $page['title'] = '地図';

    // URIから緯度経度を取得
    $page['lat'] = $this->uri->segment(3, '35.65678');
    $page['lon'] = $this->uri->segment(4, '139.733555');

    // 緯度経度の検証
    if (!$this->_checkLatLon($page['lat'], $page['lon'])) {
      die('不正な入力です');
    }

    // Yahoo!地図Web APIのURIをYahooapiモデルから取得
    $page['apiURI'] = $this->Yahooapi->getJavaScriptUri();

    // ビューを出力
    $this->load->view('station_map', $page);
  }

  /**
   * 緯度経度の検証
   * @param string $latitude
   * @param string $longitude
   * @return bool
   */
  function _checkLatLon($latitude, $longitude) {
    if (preg_match('/^[\d]{1,3}\.[\d]{0,15}$/', $latitude) 
        && preg_match('/^[\d]{1,3}\.[\d]{0,15}$/', $longitude)
    ) {
      return TRUE;
    } else {
      return FALSE;
    }
  }
}

/* End of file station.php */
/* Location: ./system/application/controllers/station.php */