<?php
/* <meta content="charset=UTF-8"> */

class Welcome extends Controller
{
  /**
   * コンストラクター
   * @access public
   * @return void
   */
  function Welcome() {
    // 親クラスのコンストラクターを実行
    parent::Controller();

    // ライブラリーをロード
    $this->load->library(array('pagination', 'session'));
    // ヘルパーをロード
    $this->load->helper(array('url', 'security', 'html'));
    // Gnaviapiモデルをロード
    $this->load->model('Gnaviapi');
    // 設定ファイルをロード
    $this->config->load('gurume');

    // GnaviapiモデルにぐるなびのアプリケーションIDをセット
    $this->Gnaviapi->setApiKey($this->config->item('gurunav'));
  }

  /**
   * 検索ページ
   * @return void
   */
  function index() {
    // ビューへ渡す配列変数を作成
    $page = array();
    // タイトルを設定
    $page['title'] = 'グルメMAP';

    // カテゴリーリストのデータを取得
    $this->_createSearchForm($page);

    // 検索フォームの値を設定
    $page['searchText'] = '';

    // メインの表示テキストを設定
    $page['appMain'] = 'グルメMAPへようこそ';

    // セッションに保存した検索条件をクリアする
    $arrayItems = array('search' => '', 'category' => '');
    $this->session->unset_userdata($arrayItems);

    // ビューを出力
    $this->load->view('welcome_index', $page);
  }

  /**
   * 飲食店の一覧ページ
   * @param string $offset
   * @return void
   */
  function search($offset = '0') {
    // ページ番号の検証
    if (ctype_digit($offset)) {
      // Gnaviapiモデルにページ番号を設定する
      $this->Gnaviapi->setOffset($offset + 1);
    } else {
      // 数字でないページ番号は不正な入力なので即座に終了
      die('不正な入力です');
    }

    // ビューへ渡す配列変数を作成
    $page = array();
    // タイトルを設定
    $page['title'] = '検索結果';

    if ($_SERVER['REQUEST_METHOD'] == 'POST') {
      // POSTされた場合
      // Formバリデーション（検証）クラスを読み込む
      $this->load->library('form_validation');

      // フォームの検証ルールの設定
      $this->form_validation->set_rules('search', '住所', 
                               'checkNull|checkEncoding|max_length[30]');
      $this->form_validation->set_rules('category', '種類', 
         'checkNull|checkEncoding|alpha_numeric|callback__checkCategory');

      // フォームの検証
      if ($this->form_validation->run() === FALSE) {
        // 検証エラーの場合
        $page['appMain']    = '入力が正しくありません';
        $page['searchText'] = '';
        // カテゴリーリストのデータを取得
        $this->_createSearchForm($page);
        // ビューを表示
        $this->load->view('welcome_index', $page);
        // このメソッドを終了
        return;
      }

      // 検証をパスした場合
      // POSTされた値を変数に代入
      $category = $this->input->post('category', TRUE);
      $search   = $this->input->post('search', TRUE);
      if ($category === FALSE) {
        // カテゴリーがPOSTされなかった場合
        $category = 'ALL';
      }

      // 次のページに検索条件を渡すためにセッションへ
      // 変数$searchと$categoryを保存する
      $session['search']   = $search;
      $session['category'] = $category;
      $this->session->set_userdata($session);
    } else {
      // POSTされなかった場合、セッションから値を取得
      $category = $this->session->userdata('category');
      $search   = $this->session->userdata('search');
    }

    // カテゴリーリストのデータを取得
    $this->_createSearchForm($page, $category);

    // 検索フォームの値を代入
    $page['searchText'] = $search;

    // 変数$searchが空以外ならGnaviapiモデルへ設定
    if ($search != '') {
      $this->Gnaviapi->setAddress($search);
    }
    
    // 変数$categoryがALL以外ならGnaviapiモデルへ設定
    if ($category != 'ALL') {
      $this->Gnaviapi->setCategory($category);
    }

    $notFound = FALSE;      // 検索結果が0件かどうか
    $storeLists = array();  // 飲食店データを保存する変数を初期化
 
    try {
      // Gnaviapiモデルから飲食店の一覧を取得する
      $storeLists = $this->Gnaviapi->get();
    }
    catch (Exception $e) {
      if ($e->getCode() == 600) {
        // 検索結果が0件の場合
        $notFound = TRUE;
      } else {
        // @todo エラーページ
        echo $e->getMessage(), '：', $e->getCode();
        exit();
      }
    }

    // 取得した飲食店のデータをXSSフィルタに通す
    $storeLists = $this->input->xss_clean($storeLists);

    if ($notFound) {
      // 検索結果が0件の場合
      $page['appMain'] = '見つかりませんでした';
    } else {
      // ページネーションのHTMLを作成
      $storeLists['pagination'] = 
                          $this->_paginate($storeLists['total_hit_count'], 
                                           $storeLists['hit_per_page']);

      // 表示する飲食店のリストを配列変数$pageに代入
      $page['appMain'] = $storeLists;
    }

    // ビューを表示
    $this->load->view('welcome_index', $page);
  }

  /**
   * ページネーションの処理
   * @param int $total_hit_count
   * @param int $hit_per_page
   * @return string
   */
  function _paginate($total_hit_count, $hit_per_page) {
      // ページの元になるURIを設定
      $config['base_url'] = $this->config->site_url('welcome/search/');

      // ページ数の計算
      // 本来は総件数を設定するが、ここでは1ページに表示する件数で割り算し
      // ページ数を設定している
      $total_rows = ceil($total_hit_count / $hit_per_page);

      // ぐるなびWebサービスの仕様でリクエストで99以上を送れないため
      // 合計が99以上なら99にする
      if ($total_rows > 99) {
        $total_rows = 99;
      }

      // 合計ページ数を設定
      $config['total_rows'] = $total_rows;

      // 本来は1ページに表示する件数を設定するが、1ページに表示する件数は
      // total_rowsに反映済みのため1を設定する
      $config['per_page'] = 1;

      // ページネーションクラスの初期化
      $this->pagination->initialize($config);

      // ページネーションのHTMLを返す
      return $this->pagination->create_links();
  }

  /**
   * Gnaviapiモデルからカテゴリーリストを作成する
   * @param $page (参照渡し)
   * @param $category
   * @return void
   */
  function _createSearchForm(&$page, $category = '') {
    try {
      // Gnaviapiモデルよりカテゴリーリストを取り出す
      $categoryLists = $this->Gnaviapi->getCategoryList();
    }
    catch (Exception $e) {
      // @todo エラーページ
      echo $e->getMessage(), '：', $e->getCode();
      exit();
    }
    //var_dump($categoryLists);

    // 配列の最初に全部を選択できるように選択肢を追加
    $option['category_l_code'] = 'ALL';
    $option['category_l_name'] = '全部';
    array_unshift($categoryLists, $option);

    // Gnaviapiモデルより取得したカテゴリーリストを処理
    foreach ($categoryLists as $item) {
      $option = array();
      $option['value'] = $item['category_l_code'];
      $option['name']  = $item['category_l_name'];
      // 選択されているカテゴリーの場合、selected属性を付ける
      if ($option['value'] == $category) {
        $option['selected'] = ' selected="selected"';
      } else {
        $option['selected'] = '';
      }
      // ビューに渡す$pageに代入
      $page['categoryLists'][] = $option;
    }
  }

  /**
   * ユーザー定義の検証メソッド
   * カテゴリーの値をチェック
   * @param string $str
   * @return bool
   */
  function _checkCategory($str) {
    if (is_null($str)) {
      return TRUE;
    }

    try {
      // Gnaviapiモデルよりカテゴリーリストを取り出す
      $categoryLists = $this->Gnaviapi->getCategoryList();
    }
    catch (Exception $e) {
      // @todo エラーページ
      echo $e->getMessage(), '：', $e->getCode();
      exit();
    }

    foreach ($categoryLists as $item) {
      $category = $item['category_l_code'];
      if ($category == $str) {
        return TRUE;
      }
    }

    if ($str == 'ALL') {
      return TRUE;
    }

    die('不正な入力です');
  }
}

/* End of file welcome.php */
/* Location: ./system/application/controllers/welcome.php */
