<?php
/* <meta content="charset=UTF-8"> */

/**
 * Yahoo!地図Web API検索モデル
 *
 */
class Yahooapi extends Model
{
  /**
   * Web APIのURI
   * @var string
   */
  const APIURI    = 'http://map.yahooapis.jp/LocalSearchService/V1/';
  const JS_APIURI = 'http://map.yahooapis.jp/MapsService/js/V2/';

  /**
   * WebサービスのアプリケーションID
   * @access private
   * @var string アプリケーションID
   */
  private $_apiKey;

  /**
   * Webサービスへ渡すURIのパラメータ
   * @var array
   */
  private $_parameters;

  /**
   * コンストラクター
   * @return void
   */
  public function __construct() {
    // 親クラスのコンストラクターを実行
    parent::__construct();

    // 検索パラメータを設定
    $this->_parameters = array(
      'dist'     => 15,	        // 距離を15kmに
      'category' => 'station',  // 検索対象を駅に
      'o'        => 'json'	    // 出力タイプをJSONに
    );
  }

  /**
   * アプリケーションIDを設定する
   * @param string $apiKey
   * @return void
   */
  public function setApiKey($apiKey) {
    $this->_apiKey = $apiKey;
  }

  /**
   * 緯度を設定する
   * @param string $latitude
   * @return object Yahooapi
   */
  public function setLatitude($latitude) {
    $this->_parameters['lat'] = $latitude;
  }

  /**
   * 経度を設定する
   * @param string $longitude
   * @return object Yahooapi
   */
  public function setLongitude($longitude) {
    $this->_parameters['lon'] = $longitude;
  }

  /**
   * Web APIから取得したデータを返す
   * @return object
   * @throws Exception [取得できない場合]
   */
  public function get() {
    // GETリクエストのタイムアウト設定（5秒）
    $opts = array('http' =>
                  array('timeout' => 5)
            );
    $context  = stream_context_create($opts);
    // Web APIへリクエスト送信
    $json = file_get_contents($this->_build(), 0, $context);
    // リクエストが失敗したかチェック
    if ($json === FALSE) {
      throw new Exception('Access Error', 0);
    }

    // JSON形式のデータをオブジェクトに変換
    $ret = json_decode($json);

    // Web APIのレスポンスがエラーか確認
    if (isset($json->Error)) {
      throw new Exception('YahooApi Error: ' . $json->Error->Message);
    }

    return $ret;
  }

  /**
   * URIを組み立てる
   * @param string $searchPath URIPath
   * @return string URI
   */
  private function _build($searchPath = 'LocalSearch') {
    $uri = self::APIURI . $searchPath . '?appid=' . $this->_apiKey;

    $parameters = array();
    foreach ($this->_parameters as $key => $val) {
      $parameters[] = $key . '=' . urlencode($val);
    }

    $uri .= '&' . implode('&', $parameters);
    return  $uri;
  }

  /**
   * JavaScript版地図のURIを返す
   * @return string URI
   */
  public function getJavaScriptUri() {
    $uri = self::JS_APIURI . '?appid=' . $this->_apiKey;
    return $uri;
  }
}

/* End of file yahooapi.php */
/* Location: ./system/application/models/yahooapi.php */
